@@ -12,7 +12,7 @@ try:
 except:
     pass
 
-version = '0.123'
+version = '0.124'
 
 import re
 import tempfile
@@ -860,7 +860,7 @@ def imwrite(path=None, img=None, jpeg_quality=95, print_assumptions=True, atomic
     
     if atomic:
         path_final = path
-        path = path.replace('.', f'_strRand(10).')
+        path = path.replace('.', f'_{strRand(10)}.')
     
     if path[-4:] == '.jpg' or path[-4:] == '.jpeg':
         cv2.imwrite(path, img[:, :, [2, 1, 0]], [int(cv2.IMWRITE_JPEG_QUALITY), jpeg_quality])
